@@ -9,19 +9,17 @@ rbugs2coda <- function(model, burnin = NULL, thin = NULL)
 
     obj <- list()
     for (i in 1:model$n.chain)
-      obj <- c(obj,list(as.mcmc(model[[chain.name[i]]])))
+      obj <- c(obj,list(coda::as.mcmc(model[[chain.name[i]]])))
     
     if(length(burnin) != 0){
       for (i in 1:model$n.chain)
-       obj[[i]] <- mcmc(obj[[i]], start = burnin, end = nrow(obj[[i]])) 
+       obj[[i]] <- coda::mcmc(obj[[i]], start = burnin, end = nrow(obj[[i]])) 
     } 
     
     if(length(thin) != 0){
       for (i in 1:model$n.chain)
-       obj[[i]] <- mcmc(obj[[i]], start = 1, end = nrow(obj[[i]]), thin = thin) 
+       obj[[i]] <- coda::mcmc(obj[[i]], start = 1, end = nrow(obj[[i]]), thin = thin) 
     }
     
-    obj <- as.mcmc.list(obj)
-    
-    obj
+    coda::as.mcmc.list(obj)
 }
